<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Smazat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Na celou obrazovku</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Promítání</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Export</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopírovat</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Otočit doprava</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Otočit doleva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Informace o fotce</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Informace o videu</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Obnovit</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Nepojmenované</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Nové album</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Opravdu chcete toto album smazat?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Koš</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Koš</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Nebo fotky přetáhněte sem</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Naimportovat vše</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importovat do:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Systémový disk</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Jednotka je zaneprázdněná. Nyní ji nelze vysunout</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovat</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Načítání…</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>Po uplynutí na nich zobrazeného počtu dnů budou soubory nadobro smazány</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stažené</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Plocha</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videa</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Uložit do:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvalita:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Vybrat jiné složky</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Název souboru nemůže být prázdný</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>už existuje. Má být nahrazeno?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zachycení obsahu obrazovky</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Kreslit</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(kopie)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 jednotka</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Prázdný %1 disk</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 zašifrováno</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 svazek</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Exportovat fotky</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Mazání…</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Obnovování…</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>Opravdu chcete tento soubor natrvalo smazat?</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>Už ho není možné obnovit</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>Opravdu chcete natrvalo smazat %1 souborů?</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>Už je není možné obnovit</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>Opravdu chcete tento soubor lokálně smazat?</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>Je možné ho obnovit z koše</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>Opravdu chcete lokálně smazat %1 souborů?</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>Je možné je obnovit z koše</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importovat</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 fotka</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n fotka</numerusform>
            <numerusform>%n fotky</numerusform>
            <numerusform>%n fotek</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
            <numerusform>%n videa</numerusform>
            <numerusform>%n videí</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n položka</numerusform>
            <numerusform>%n položky</numerusform>
            <numerusform>%n položek</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importovat fotky a videa</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>Nebo je přetáhněte sem</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Všechny fotky a videa</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Nenalezeny žádné fotky či videa</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Zařízení</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Alba</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Album je šikovný správce pro zobrazování a uspořádávání fotek a videí</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotky</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Přejmenovat album</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Album „%1“ odstraněno</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Úspěšně přidáno do „%1“</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Úspěšně naimportováno</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Import se nezdařil</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Export se nezdařil</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Úspěšně exportováno</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Všechny fotky</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Časové osy</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Alba</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Opustit celou obrazovku/promítání</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Přiblížit</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Oddálit</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>O stránku výše</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>O stránku níže</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importování…</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Všechny fotky a videa</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importovat fotky a videa</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Nenalezeny žádné fotky či videa</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Exportovat fotky</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Importovat fotky/videa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Informace o fotce/videu</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>Nahrát fotky a videa</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>Importovat složky</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>Import přerušen</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>Toto umístění se nedaří přidat, zkuste přidat jiné</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>Umístění už existuje</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>Nepodařilo se obnovit %1 souborů: název souboru je příliš dlouhý</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Blesk</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Datum pořízení</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Režim expozice</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Expoziční program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Expoziční čas</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Ohnisková vzdálenost</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>Citlivost ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Nejvyšší clona</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Režim měření</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Vyvážení bílé</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Vyrovnání blesku</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model fotoaparátu</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model objektivu</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Barevný prostor</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Štítek</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Nic nenalezeno</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Systémový disk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Zrušit výběr</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importováno </translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %3-%2-%1 v %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Okamžik importu</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Zrušit výběr všeho</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotky</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videa</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Nic nenalezeno</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importování…</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>Naimportováno %1/%2 položek</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>Smazáno %1/%2 položek</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>Naimportováno %1 položek, nepodařilo se u %2 položek</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>Vybrána 1 fotka</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>Vybráno 1 video</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>Fotka/video už existuje</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>Vybrána %n fotka</numerusform>
            <numerusform>Vybrány %n fotky</numerusform>
            <numerusform>Vybráno %n fotek</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>Vybráno %n video</numerusform>
            <numerusform>Vybrána %n videa</numerusform>
            <numerusform>Vybráno %n videí</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>Vybrána %n položka</numerusform>
            <numerusform>Vybrány %n položky</numerusform>
            <numerusform>Vybráno %n položek</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>Naimportováno %1 položek, %2 položek už existuje</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nic nenalezeno</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Výsledky hledání</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>Nalezena 1 fotka</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>nalezeno %n video</numerusform>
            <numerusform>nalezena %n videa</numerusform>
            <numerusform>nalezeno %n videí</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>Nalezeno 1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>nalezena %n položka</numerusform>
            <numerusform>nalezeny %n položky</numerusform>
            <numerusform>nalezeno %n položek</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>Nalezena %1 fotka</numerusform>
            <numerusform>Nalezeno %1 fotek</numerusform>
            <numerusform>Nalezeno %1 fotek</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 fotka</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n fotka</numerusform>
            <numerusform>%n fotky</numerusform>
            <numerusform>%n fotek</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
            <numerusform>%n videa</numerusform>
            <numerusform>%n videí</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Importuje se: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Ukládá se: %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Na celou obrazovku</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Informace o fotce</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Přidat do alba</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Informace o videu</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dní</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 fotka</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n fotka</numerusform>
            <numerusform>%n fotky</numerusform>
            <numerusform>%n fotek</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
            <numerusform>%n videa</numerusform>
            <numerusform>%n videí</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n položka</numerusform>
            <numerusform>%n položky</numerusform>
            <numerusform>%n položek</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Informace o kodeku</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Informace o zvuku</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Identifikátor kodeku videa</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Bitová rychlost kodeku videa</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>SN/S</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Proporce</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Rozlišení</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Identifikátor kodeku zvuku</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Bitová rychlost kodeku zvuku</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Zvuk digit</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Frekvence vzorkování</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trvání</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Popis umístění</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Informace o videu</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Datum pořízení</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
</context>
</TS>
